/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvMath.h"
#include "HvSignalBiquad.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlBinop.h"
#include "HvControlVar.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvControlCast.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_B02kDnM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kupL5ZNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Kh7T4Mj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QD0fnlxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DtxM995T_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ZfuN1A1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FraufON4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jmXEkjiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o84dhwz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LdGZxkel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Qc5Itmwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T6RUWrFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GzvztlVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZOaxxgaO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NzZmOzEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lh15301Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fjyDGJq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wz0GzwZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EaKlUNLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_81iKKp03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8N36bO20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WwWqSMV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v7BAyZOZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xz0fDshV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M6fJUjKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eB6Np7cD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VI2HWIYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MSLbqH2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_35vNTDmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EANXfzGg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nOTuuhwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uvTKxmKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HVeVlllh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yYzslIhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_If8FbLZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wA7o8lZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zt4e3yYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3qCHxlaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IIrQBFoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RS6BeWsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_syAxWpbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QNhxeGlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PD9sEnIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hSIXuEeM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v45deRtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dp6iFCqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JpfkD0ho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IB7rbEVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8f4JWSQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_egZ4FOZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FFqJ7qsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LihRTbh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IymdAW44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WFHooBTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gXZRLooR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UzdUYKWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MKIa2PAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l4eKokoS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_foF2mwD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nTS1VTBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cp7kGxW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2bJc0ob8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u5q7kxL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWTyDNix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SbKuhVqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lTfIpzJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ez8p4TUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v1pgGm9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gnePUJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v5K6YvqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y51sSl3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LaqUTtQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lpa1ujXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ge8KfDxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cEoYqLPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z1HC7NhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HqMqLfvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2tLEcfI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MjHFKOLj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_S4Z3sQQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_91huKjHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xQ1E9K4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CUsdvINZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aEBHUHTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F353yiLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_t4X1ohn4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dvUqKbro_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_g9CUwuX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uOHJ3PVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hgkkNfcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mpbkyoEg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UsdFeisW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AhLOVB43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_x9hODt5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LbbR2xvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ch1ZkhbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XW5h9lyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dGvFvcl1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WLBaw19c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5R8oGpTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OUeQETwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_p0PZdxW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yiEJGHJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T3xYGnPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tezi3dxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ktri6zAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iOzexMJ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OWtPlHka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DBlahyUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mc8hkIz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NkpdZHjv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xBrbkPKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z6542Kns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yydL0GVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UJP8MifW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zrNthIae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qxo4VQJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pTScQVsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R5dF1UEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VEIMh0Qy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EXB3Pnll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RRjUJNxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8yivIDb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZWVyixw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bNxXDaXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3lWMNZEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IuYhRZ9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5P3Ca2yX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oJLJjhRG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VndM0Hc0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tFokLy7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WTzoH4iJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b1T2mQ2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k25AO28z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KXKjVmYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nVk5O6Se_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S5YdHR43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2huzjHUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sixQoTsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fkwqnt4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bcC48fQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XNWqFrWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1lMKybsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BZ9ZsGA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2UgSHRhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VS4OvHXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iVehMqtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_23bhmgqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AD3FmuwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kkz9bCYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vNYR8Pxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8vXud8GP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6VaFE7wK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f664AqMh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bAWpkHfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y3KwJ442_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7FrBoUPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lzorB6Lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rTKjaQ2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z8YDelJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YWwoqI1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cpWfE282_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xTsqBeaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJSjQL9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_idSs7PtF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_U6Ur7ufE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HWztPTG2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S4kCTrxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VQxhafzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2lJw3Vf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GH0yqhZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KYWzJlwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o5nQAniK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SH2pnKe7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jn4lB4Hk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EnnvoJnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gXFroO3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rVDqezGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FRxstFqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LHtKGy8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZqK0WoBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VDuuv1vm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fbxkKNZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5U7qPlbW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HfsH6KiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9DWwcIA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_95Wn1MbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Td4mUPJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QdTphDb6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q1uFYBNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LOvzlw31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ji1feV3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gUcrJCXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zDlWRfsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AqMhtyBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rWPGZgoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nb3Vx8EJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4D2zXW0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aCbxErjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SYz2HMQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pSJfEhnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ELxblgYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6aIpVHso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v1rNZkqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Qq4aXeU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tdv9dtdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VfvlHgSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Dp6gpErM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FavYB49q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FoJ2QDOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bsbe0H8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vi1iDX4P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WXj9Zq45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQ1CpjvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uC8D1aqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vfUMZj4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P0zo5HQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4jvVFFPW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LsI1XXGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9c8vxUxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iqjAMarm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QZx6EJQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Ys8kgzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ac6qU1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_597WUn2k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lh2gmUB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NhJdrkPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gKOtm7xK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVeIIaIR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rw3UiP7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EjCNm4dA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MRIpZYM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EiSMgiQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Bq772Thi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GWVQVuqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ovo3k603_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jxBuq2Ad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bBl2phV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZF31yZhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fut3nUYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2IwhZViW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IPY2cEXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WT31yBlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dFWfV2i6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MWPLCqEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_53T4YhiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6bQaP2Gr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WTfmqs7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1hI5sqWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1LXoTeUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXsE6FLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aHOlwhaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nAVAuTUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_459jDDDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DvriYJC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8gEJnTUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8AZno94j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ziMz387C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yS25lm8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2Ey08stm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iyOM4WCz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y9Qb9ZI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vbaEMq1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_reLVNsX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1ZDSSOzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KSgLWzkn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_m7CH5J0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xoHIX5RN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Hc9awpmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lk8Dv7Up_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gUIDwp12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JIuWQNkI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zTW3dSZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cIU01Oqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v6bDq5Wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d7LCWMVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8xt3j23O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HKo4zdFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oQTg0DOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n5gewDRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tzqwMG9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SoZlfIn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jargmT64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hq6AkW9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zB75D4O5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GzxqKMNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UEqNsaGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jNVBotPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jx8K2zBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o5moYQsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Lengetd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t2XUdO48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1bfdHqvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jLluDBHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_S6IKDpeO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EGcsyQ1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ufLefn4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CP7TY1nf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6IbLkEdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iKLnlw80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F3WqyBk2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yx9K5409_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HgkqjnKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YOcY86EA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kwU45YHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kqsT0gEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LHYg9g8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TJpatW2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0stDYXZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PPOmDfYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HpzuTlCC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zyCNqE6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sTZAsGkB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kHB9iAO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H2W34SNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fG2p4jWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pSf73w9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wvKy3GyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G6eJQVau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uu7k9Afw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NB23Ypyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4wCNoHq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X2Q0lj1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QV0WSxzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Crfo4d9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3XNJlYFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VqKc3mx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SZvUDKKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kPi3F36n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5uKht8WH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZnmGfHmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YlQ1Ev7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CQoCvyej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aCUk2gGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ivj6cGDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LhS2nO1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f8M7DUZK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oh8N81eF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sjqDCwyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WF8NFTRT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_r7G9OmTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LC0LFcCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rtbWVO1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kzHD4kvk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_v14ZHExI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JkhhBQzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sCbEbsYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NoLbiOLa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GpZTugdm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ln5UaYeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FVLeIBIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Fn6fX37q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UFY6DiFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_96JDEnLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PuXuENec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V7ruKEq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uyFiTOj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pfPkWbyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rzifKTuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DlzHGIvt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FuXrvbow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sAU2u3Th_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nXnfIc9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uAeNvcG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7W5cnJRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5W8tmLWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdB03Xwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3CnrEN6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sQNrVGJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_mdNI8LKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IxMfg24Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OR48qgsx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vTZygR7i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sOsxDkkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8MbuzBy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Znk8AoRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pB7WPzSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4S5NXd2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PwHGW5JU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JUPaadK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mCGK9NWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dcotGE5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wFKe479g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WFkV084U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LXSrepYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Of3HMZJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x2Wpml3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XjTVObJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YQhAo6Yh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_E3MYQoI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RC2udNtU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ssjO3lWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u1SRLLP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BVU64ayu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ggwqqxZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XKoUlQM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PUeEUuM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q4uNqEL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_09TcSPzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FaLhFBvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L2MPA5Ot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b1RpTOxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dBmTYW82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cw0VMUFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QONX3xX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ABRNDj0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9rkAgB2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yBVsY0bU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AW8WAPJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f26fmPQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OZuOVKHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aQufCUHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MsywQvCo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bgHHUrhc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_57NGpYOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Obek3tQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SpHJLfaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OFHglL23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3bZaLfda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hOC71kti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tIPrVusk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ah960XzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p7wIE847_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Um7fw3rA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qLPwq1m8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OQ1LwpmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1u3FDx1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_41p560A1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G0TMWKjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P3TZPZB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9eAuU5ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oJ67W1G0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qfilc8ST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wo447MNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dyQOEUN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0eqw3F9f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bu3aTm6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NVrdo6vE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w0RiZ5i6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sCdOlgUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yuYO82YY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ah0Y9Dar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WWaqqzWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tOy1Pe9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1XcM1hlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AigADOjT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WpCBU9Z6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nkg7S1fN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yZWPnGcy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_feOoEzPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d9a01TSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ouoJTSC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U95FpkqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ow2l8Nzy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b733VE6c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1uOwWS4V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IiJ2n8z3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CNg2MFJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WCrUAfIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lo5SZXGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8WhvcZOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gv4Ydv3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iVDMdKhV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H8LHjtYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SkTnu0VN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EyLoManG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PHfXrTr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KX0emTIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pkCELeEZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gSrJ3cXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wZtMpqGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qXQzH9cD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hBnQvDMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E2OKXLYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0p07kJ2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yaw43jsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_irISquyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XhjI0sEM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_csjakje6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BkoozgJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jRrhxLYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3zIVCVJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GTeiMuMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p7GKO8CK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDJxla3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y33WSTUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SuLRPTgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cfWCWgMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rDHzUp3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cm8xcz3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OQsyVDNn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2QMb4ITp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gDbMTrrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Vp0X25tg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_88Kz8VCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nM25BPco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yPoZiRdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MBmF1H0j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_q65ve7WP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HvLl8fO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uhJ6hlVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xxpyp15V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9eEFHm0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tm4tSbzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aYk8TsSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5ihrqmcV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GKURRR9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UU47BoiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bOEfhDRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hItxXhbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rw0ybWSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xHwt8tAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h5Xm1LUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xnLe1Ee4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fkfJV1M1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wp0SBvjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vlIjCzJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0IV1tdDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CKwmCi80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bEy0wDmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cV1Ca6Mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ihUZcZYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZCaRxWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3O2fa3fK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YkhygAIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aMVQXFQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UNWKaUzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iSyyWy2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_z6opk75Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uNjGwt1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WvBPJqJQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BMk0EyGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wY787swj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1DU3KUPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KyDdnmAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DtiLfzMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9Ruc9aaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gc1aPfbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GJZ5zv0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NX89H62x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c5xeKhQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mihWz2Ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dEkiGv8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5tvp47b3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dKq24g4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UCktKukU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0H8hBIJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IwAYcGx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_S1Ow8DPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KvdHO3L8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rgjLGeJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dsrqBP5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kbWfoeVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uqo8JZAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KCpK9nhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0HasJXFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lTDA2wbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_liR2ah1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MuEqYNex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gxup8dEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uGdhUZ07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PUj6gwDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wpoSlajG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yjRkCfcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_w7J2snC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_d1y5ieAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nLIXptl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cZRZtS8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gEFhxnYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gSbFEUqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zxXmdTS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MaqjcbS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BQx0EPUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e139hu6v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_K9LI2W3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RLLRX8FE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X8IFh7PB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YrYMUJfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5gO3Z5vh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qVHUfY03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pDsZFDmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_bZhG2mJA;
  SignalLine sLine_EXpbeNjS;
  SignalLine sLine_JldsxYdV;
  SignalLine sLine_gvkiHgnT;
  SignalLine sLine_qBf0oTQr;
  SignalBiquad sBiquad_s_n8Fqd2d3;
  SignalLine sLine_ydtI3lBz;
  SignalLine sLine_GGFk8OIR;
  SignalLine sLine_LBKTejcO;
  SignalLine sLine_L0E8zzyz;
  SignalBiquad sBiquad_s_VQWH99BJ;
  SignalLine sLine_NQaBwCV9;
  SignalLine sLine_rXPmsFRb;
  SignalLine sLine_wFscdfRp;
  SignalLine sLine_rKcKjTrb;
  SignalLine sLine_vL8QbiQ4;
  SignalBiquad sBiquad_s_ciHuCBsJ;
  SignalLine sLine_mLmYYCjb;
  SignalLine sLine_t1v4tUSr;
  SignalLine sLine_yMlU0Hot;
  SignalLine sLine_1p5IABSn;
  SignalLine sLine_0iIXP59a;
  SignalBiquad sBiquad_s_3Sls51ut;
  SignalLine sLine_GlMVmWy3;
  SignalLine sLine_QrTTpkCN;
  SignalLine sLine_mYLjS90O;
  SignalLine sLine_5PZGh9zr;
  SignalBiquad sBiquad_s_K3y1Aswr;
  SignalLine sLine_MD7JkkXP;
  SignalLine sLine_rNc75q6f;
  SignalLine sLine_tPCoPcpg;
  SignalLine sLine_9UES8ZTy;
  SignalLine sLine_yUrY0Y5O;
  SignalBiquad sBiquad_s_Kwh8jbzQ;
  ControlVar cVar_B02kDnM0;
  ControlVar cVar_kupL5ZNj;
  ControlVar cVar_Kh7T4Mj8;
  ControlVar cVar_QD0fnlxe;
  ControlSlice cSlice_ZfuN1A1q;
  ControlVar cVar_FraufON4;
  ControlVar cVar_o84dhwz2;
  ControlIf cIf_LdGZxkel;
  ControlIf cIf_Qc5Itmwv;
  ControlBinop cBinop_GzvztlVJ;
  ControlBinop cBinop_ZOaxxgaO;
  ControlBinop cBinop_fjyDGJq1;
  ControlBinop cBinop_wz0GzwZW;
  ControlBinop cBinop_81iKKp03;
  ControlIf cIf_8N36bO20;
  ControlBinop cBinop_WwWqSMV1;
  ControlBinop cBinop_v7BAyZOZ;
  ControlBinop cBinop_M6fJUjKZ;
  ControlBinop cBinop_eB6Np7cD;
  ControlBinop cBinop_VI2HWIYJ;
  ControlVar cVar_uvTKxmKH;
  ControlIf cIf_HVeVlllh;
  ControlIf cIf_yYzslIhS;
  ControlBinop cBinop_wA7o8lZa;
  ControlBinop cBinop_zt4e3yYJ;
  ControlBinop cBinop_RS6BeWsp;
  ControlBinop cBinop_syAxWpbx;
  ControlBinop cBinop_PD9sEnIK;
  ControlIf cIf_hSIXuEeM;
  ControlBinop cBinop_v45deRtN;
  ControlBinop cBinop_Dp6iFCqR;
  ControlBinop cBinop_IB7rbEVW;
  ControlBinop cBinop_8f4JWSQf;
  ControlBinop cBinop_egZ4FOZy;
  ControlVar cVar_gXZRLooR;
  ControlIf cIf_UzdUYKWm;
  ControlIf cIf_MKIa2PAU;
  ControlBinop cBinop_foF2mwD8;
  ControlBinop cBinop_nTS1VTBk;
  ControlBinop cBinop_u5q7kxL6;
  ControlBinop cBinop_sWTyDNix;
  ControlBinop cBinop_lTfIpzJH;
  ControlIf cIf_ez8p4TUQ;
  ControlBinop cBinop_v1pgGm9B;
  ControlBinop cBinop_5gnePUJA;
  ControlBinop cBinop_y51sSl3Q;
  ControlBinop cBinop_LaqUTtQX;
  ControlBinop cBinop_lpa1ujXP;
  ControlIf cIf_2tLEcfI3;
  ControlSlice cSlice_S4Z3sQQC;
  ControlVar cVar_91huKjHy;
  ControlSlice cSlice_aEBHUHTY;
  ControlVar cVar_F353yiLW;
  ControlSlice cSlice_g9CUwuX3;
  ControlVar cVar_uOHJ3PVW;
  ControlSlice cSlice_UsdFeisW;
  ControlVar cVar_AhLOVB43;
  ControlBinop cBinop_T3xYGnPr;
  ControlBinop cBinop_ktri6zAL;
  ControlBinop cBinop_iOzexMJ2;
  ControlBinop cBinop_Mc8hkIz8;
  ControlBinop cBinop_NkpdZHjv;
  ControlBinop cBinop_xBrbkPKS;
  ControlBinop cBinop_Z6542Kns;
  ControlBinop cBinop_yydL0GVW;
  ControlVar cVar_UJP8MifW;
  ControlBinop cBinop_zrNthIae;
  ControlBinop cBinop_Qxo4VQJj;
  ControlBinop cBinop_pTScQVsf;
  ControlBinop cBinop_R5dF1UEY;
  ControlBinop cBinop_VEIMh0Qy;
  ControlBinop cBinop_EXB3Pnll;
  ControlBinop cBinop_RRjUJNxl;
  ControlBinop cBinop_XZWVyixw;
  ControlVar cVar_bNxXDaXm;
  ControlVar cVar_3lWMNZEQ;
  ControlBinop cBinop_b1T2mQ2C;
  ControlBinop cBinop_k25AO28z;
  ControlBinop cBinop_KXKjVmYO;
  ControlBinop cBinop_S5YdHR43;
  ControlBinop cBinop_2huzjHUe;
  ControlBinop cBinop_sixQoTsp;
  ControlBinop cBinop_fkwqnt4K;
  ControlBinop cBinop_bcC48fQE;
  ControlBinop cBinop_XNWqFrWC;
  ControlBinop cBinop_YWwoqI1J;
  ControlBinop cBinop_xTsqBeaC;
  ControlBinop cBinop_sJSjQL9o;
  ControlBinop cBinop_HWztPTG2;
  ControlBinop cBinop_S4kCTrxF;
  ControlBinop cBinop_VQxhafzM;
  ControlBinop cBinop_2lJw3Vf2;
  ControlBinop cBinop_GH0yqhZk;
  ControlBinop cBinop_KYWzJlwX;
  ControlBinop cBinop_o5nQAniK;
  ControlBinop cBinop_Jn4lB4Hk;
  ControlVar cVar_EnnvoJnI;
  ControlVar cVar_gXFroO3j;
  ControlVar cVar_rVDqezGM;
  ControlBinop cBinop_HfsH6KiC;
  ControlBinop cBinop_9DWwcIA7;
  ControlBinop cBinop_95Wn1MbV;
  ControlBinop cBinop_QdTphDb6;
  ControlBinop cBinop_Q1uFYBNM;
  ControlBinop cBinop_LOvzlw31;
  ControlBinop cBinop_Ji1feV3V;
  ControlBinop cBinop_gUcrJCXU;
  ControlBinop cBinop_bsbe0H8p;
  ControlBinop cBinop_WXj9Zq45;
  ControlBinop cBinop_FQ1CpjvT;
  ControlBinop cBinop_P0zo5HQh;
  ControlBinop cBinop_4jvVFFPW;
  ControlBinop cBinop_LsI1XXGG;
  ControlBinop cBinop_9c8vxUxV;
  ControlBinop cBinop_iqjAMarm;
  ControlBinop cBinop_5Ys8kgzk;
  ControlBinop cBinop_597WUn2k;
  ControlBinop cBinop_Lh2gmUB3;
  ControlBinop cBinop_gKOtm7xK;
  ControlBinop cBinop_JVeIIaIR;
  ControlBinop cBinop_rw3UiP7h;
  ControlBinop cBinop_MRIpZYM7;
  ControlVar cVar_EiSMgiQ2;
  ControlVar cVar_Bq772Thi;
  ControlVar cVar_GWVQVuqv;
  ControlBinop cBinop_IPY2cEXe;
  ControlBinop cBinop_WT31yBlR;
  ControlBinop cBinop_dFWfV2i6;
  ControlBinop cBinop_53T4YhiS;
  ControlBinop cBinop_6bQaP2Gr;
  ControlBinop cBinop_WTfmqs7s;
  ControlBinop cBinop_1hI5sqWV;
  ControlBinop cBinop_1LXoTeUI;
  ControlBinop cBinop_MXsE6FLw;
  ControlBinop cBinop_Y9Qb9ZI8;
  ControlBinop cBinop_reLVNsX4;
  ControlBinop cBinop_1ZDSSOzj;
  SignalVarf sVarf_dtMLzaxb;
  SignalVarf sVarf_UDuDg0qb;
  SignalVarf sVarf_6sS7HCQd;
  ControlSlice cSlice_m7CH5J0K;
  ControlVar cVar_xoHIX5RN;
  ControlVar cVar_lk8Dv7Up;
  ControlIf cIf_gUIDwp12;
  ControlIf cIf_JIuWQNkI;
  ControlBinop cBinop_cIU01Oqr;
  ControlBinop cBinop_v6bDq5Wj;
  ControlBinop cBinop_HKo4zdFP;
  ControlBinop cBinop_oQTg0DOW;
  ControlBinop cBinop_tzqwMG9Y;
  ControlIf cIf_SoZlfIn3;
  ControlBinop cBinop_jargmT64;
  ControlBinop cBinop_Hq6AkW9I;
  ControlBinop cBinop_GzxqKMNG;
  ControlBinop cBinop_UEqNsaGj;
  ControlBinop cBinop_jNVBotPC;
  ControlVar cVar_1bfdHqvG;
  ControlIf cIf_jLluDBHm;
  ControlIf cIf_S6IKDpeO;
  ControlBinop cBinop_7ufLefn4;
  ControlBinop cBinop_CP7TY1nf;
  ControlBinop cBinop_F3WqyBk2;
  ControlBinop cBinop_yx9K5409;
  ControlBinop cBinop_YOcY86EA;
  ControlIf cIf_kwU45YHf;
  ControlBinop cBinop_kqsT0gEK;
  ControlBinop cBinop_LHYg9g8l;
  ControlBinop cBinop_0stDYXZY;
  ControlBinop cBinop_PPOmDfYp;
  ControlBinop cBinop_HpzuTlCC;
  ControlVar cVar_fG2p4jWE;
  ControlIf cIf_pSf73w9v;
  ControlIf cIf_wvKy3GyI;
  ControlBinop cBinop_uu7k9Afw;
  ControlBinop cBinop_NB23Ypyw;
  ControlBinop cBinop_QV0WSxzl;
  ControlBinop cBinop_Crfo4d9n;
  ControlBinop cBinop_VqKc3mx5;
  ControlIf cIf_SZvUDKKZ;
  ControlBinop cBinop_kPi3F36n;
  ControlBinop cBinop_5uKht8WH;
  ControlBinop cBinop_YlQ1Ev7w;
  ControlBinop cBinop_CQoCvyej;
  ControlBinop cBinop_aCUk2gGB;
  ControlIf cIf_sjqDCwyk;
  ControlSlice cSlice_r7G9OmTi;
  ControlVar cVar_LC0LFcCq;
  ControlSlice cSlice_v14ZHExI;
  ControlVar cVar_JkhhBQzJ;
  ControlSlice cSlice_GpZTugdm;
  ControlVar cVar_Ln5UaYeY;
  ControlSlice cSlice_UFY6DiFN;
  ControlVar cVar_96JDEnLR;
  ControlBinop cBinop_7W5cnJRj;
  ControlBinop cBinop_gdB03Xwz;
  ControlBinop cBinop_3CnrEN6a;
  ControlBinop cBinop_IxMfg24Y;
  ControlBinop cBinop_OR48qgsx;
  ControlBinop cBinop_vTZygR7i;
  ControlBinop cBinop_sOsxDkkb;
  ControlBinop cBinop_8MbuzBy0;
  ControlVar cVar_Znk8AoRK;
  ControlBinop cBinop_pB7WPzSR;
  ControlBinop cBinop_4S5NXd2R;
  ControlBinop cBinop_PwHGW5JU;
  ControlBinop cBinop_JUPaadK8;
  ControlBinop cBinop_mCGK9NWx;
  ControlBinop cBinop_dcotGE5w;
  ControlBinop cBinop_wFKe479g;
  ControlBinop cBinop_LXSrepYs;
  ControlVar cVar_Of3HMZJw;
  ControlVar cVar_x2Wpml3v;
  ControlBinop cBinop_BVU64ayu;
  ControlBinop cBinop_ggwqqxZY;
  ControlBinop cBinop_XKoUlQM7;
  ControlBinop cBinop_q4uNqEL3;
  ControlBinop cBinop_09TcSPzk;
  ControlBinop cBinop_FaLhFBvN;
  ControlBinop cBinop_L2MPA5Ot;
  ControlBinop cBinop_b1RpTOxk;
  ControlBinop cBinop_dBmTYW82;
  ControlBinop cBinop_Ah960XzM;
  ControlBinop cBinop_Um7fw3rA;
  ControlBinop cBinop_qLPwq1m8;
  ControlBinop cBinop_41p560A1;
  ControlBinop cBinop_G0TMWKjG;
  ControlBinop cBinop_P3TZPZB7;
  ControlBinop cBinop_9eAuU5ur;
  ControlBinop cBinop_oJ67W1G0;
  ControlBinop cBinop_Qfilc8ST;
  ControlBinop cBinop_wo447MNa;
  ControlBinop cBinop_0eqw3F9f;
  ControlVar cVar_bu3aTm6g;
  ControlVar cVar_NVrdo6vE;
  ControlVar cVar_w0RiZ5i6;
  ControlBinop cBinop_AigADOjT;
  ControlBinop cBinop_WpCBU9Z6;
  ControlBinop cBinop_nkg7S1fN;
  ControlBinop cBinop_feOoEzPm;
  ControlBinop cBinop_d9a01TSj;
  ControlBinop cBinop_ouoJTSC0;
  ControlBinop cBinop_U95FpkqK;
  ControlBinop cBinop_Ow2l8Nzy;
  ControlBinop cBinop_qXQzH9cD;
  ControlBinop cBinop_E2OKXLYJ;
  ControlBinop cBinop_0p07kJ2d;
  ControlBinop cBinop_XhjI0sEM;
  ControlBinop cBinop_csjakje6;
  ControlBinop cBinop_BkoozgJi;
  ControlBinop cBinop_jRrhxLYI;
  ControlBinop cBinop_3zIVCVJo;
  ControlBinop cBinop_p7GKO8CK;
  ControlBinop cBinop_Y33WSTUc;
  ControlBinop cBinop_SuLRPTgW;
  ControlBinop cBinop_rDHzUp3f;
  ControlBinop cBinop_Cm8xcz3J;
  ControlBinop cBinop_OQsyVDNn;
  ControlBinop cBinop_gDbMTrrl;
  ControlVar cVar_Vp0X25tg;
  ControlVar cVar_88Kz8VCu;
  ControlVar cVar_nM25BPco;
  ControlBinop cBinop_9eEFHm0F;
  ControlBinop cBinop_tm4tSbzC;
  ControlBinop cBinop_aYk8TsSj;
  ControlBinop cBinop_GKURRR9j;
  ControlBinop cBinop_UU47BoiS;
  ControlBinop cBinop_bOEfhDRc;
  ControlBinop cBinop_hItxXhbp;
  ControlBinop cBinop_rw0ybWSG;
  ControlBinop cBinop_xHwt8tAD;
  ControlBinop cBinop_XZCaRxWV;
  ControlBinop cBinop_YkhygAIn;
  ControlBinop cBinop_aMVQXFQS;
  SignalVarf sVarf_thl23ZGW;
  SignalVarf sVarf_RANnAcef;
  SignalVarf sVarf_DJyXn6JK;
  SignalVarf sVarf_fosY6X2T;
  SignalVarf sVarf_KtK32VLp;
  SignalVarf sVarf_alyJcKR4;
  SignalVarf sVarf_IDWwfouK;
  SignalVarf sVarf_8A2HrBLB;
  SignalVarf sVarf_XHHpa2sx;
  ControlVar cVar_UNWKaUzO;
  ControlVar cVar_iSyyWy2b;
  ControlBinop cBinop_1DU3KUPp;
  ControlBinop cBinop_KyDdnmAL;
  ControlBinop cBinop_DtiLfzMR;
  ControlBinop cBinop_gc1aPfbn;
  ControlBinop cBinop_GJZ5zv0F;
  ControlBinop cBinop_NX89H62x;
  ControlBinop cBinop_c5xeKhQy;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
