/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_bZhG2mJA);
  numBytes += sLine_init(&sLine_EXpbeNjS);
  numBytes += sLine_init(&sLine_JldsxYdV);
  numBytes += sLine_init(&sLine_gvkiHgnT);
  numBytes += sLine_init(&sLine_qBf0oTQr);
  numBytes += sBiquad_init(&sBiquad_s_n8Fqd2d3);
  numBytes += sLine_init(&sLine_ydtI3lBz);
  numBytes += sLine_init(&sLine_GGFk8OIR);
  numBytes += sLine_init(&sLine_LBKTejcO);
  numBytes += sLine_init(&sLine_L0E8zzyz);
  numBytes += sBiquad_init(&sBiquad_s_VQWH99BJ);
  numBytes += sLine_init(&sLine_NQaBwCV9);
  numBytes += sLine_init(&sLine_rXPmsFRb);
  numBytes += sLine_init(&sLine_wFscdfRp);
  numBytes += sLine_init(&sLine_rKcKjTrb);
  numBytes += sLine_init(&sLine_vL8QbiQ4);
  numBytes += sBiquad_init(&sBiquad_s_ciHuCBsJ);
  numBytes += sLine_init(&sLine_mLmYYCjb);
  numBytes += sLine_init(&sLine_t1v4tUSr);
  numBytes += sLine_init(&sLine_yMlU0Hot);
  numBytes += sLine_init(&sLine_1p5IABSn);
  numBytes += sLine_init(&sLine_0iIXP59a);
  numBytes += sBiquad_init(&sBiquad_s_3Sls51ut);
  numBytes += sLine_init(&sLine_GlMVmWy3);
  numBytes += sLine_init(&sLine_QrTTpkCN);
  numBytes += sLine_init(&sLine_mYLjS90O);
  numBytes += sLine_init(&sLine_5PZGh9zr);
  numBytes += sBiquad_init(&sBiquad_s_K3y1Aswr);
  numBytes += sLine_init(&sLine_MD7JkkXP);
  numBytes += sLine_init(&sLine_rNc75q6f);
  numBytes += sLine_init(&sLine_tPCoPcpg);
  numBytes += sLine_init(&sLine_9UES8ZTy);
  numBytes += sLine_init(&sLine_yUrY0Y5O);
  numBytes += sBiquad_init(&sBiquad_s_Kwh8jbzQ);
  numBytes += cVar_init_f(&cVar_B02kDnM0, 0.0f);
  numBytes += cVar_init_f(&cVar_kupL5ZNj, 0.0f);
  numBytes += cVar_init_f(&cVar_Kh7T4Mj8, 0.0f);
  numBytes += cVar_init_f(&cVar_QD0fnlxe, 0.0f);
  numBytes += cSlice_init(&cSlice_ZfuN1A1q, 1, -1);
  numBytes += cVar_init_f(&cVar_FraufON4, 1337.0f);
  numBytes += cVar_init_f(&cVar_o84dhwz2, 0.0f);
  numBytes += cIf_init(&cIf_LdGZxkel, false);
  numBytes += cIf_init(&cIf_Qc5Itmwv, false);
  numBytes += cBinop_init(&cBinop_GzvztlVJ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_8N36bO20, false);
  numBytes += cBinop_init(&cBinop_M6fJUjKZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eB6Np7cD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VI2HWIYJ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_uvTKxmKH, 0.0f);
  numBytes += cIf_init(&cIf_HVeVlllh, false);
  numBytes += cIf_init(&cIf_yYzslIhS, false);
  numBytes += cBinop_init(&cBinop_wA7o8lZa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_hSIXuEeM, false);
  numBytes += cBinop_init(&cBinop_IB7rbEVW, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8f4JWSQf, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_egZ4FOZy, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_gXZRLooR, 0.0f);
  numBytes += cIf_init(&cIf_UzdUYKWm, false);
  numBytes += cIf_init(&cIf_MKIa2PAU, false);
  numBytes += cBinop_init(&cBinop_foF2mwD8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ez8p4TUQ, false);
  numBytes += cBinop_init(&cBinop_y51sSl3Q, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_LaqUTtQX, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_lpa1ujXP, -15.0f); // __eq
  numBytes += cIf_init(&cIf_2tLEcfI3, false);
  numBytes += cSlice_init(&cSlice_S4Z3sQQC, 1, -1);
  numBytes += cVar_init_f(&cVar_91huKjHy, 0.0f);
  numBytes += cSlice_init(&cSlice_aEBHUHTY, 1, -1);
  numBytes += cVar_init_f(&cVar_F353yiLW, 0.0f);
  numBytes += cSlice_init(&cSlice_g9CUwuX3, 1, -1);
  numBytes += cVar_init_f(&cVar_uOHJ3PVW, 0.0f);
  numBytes += cSlice_init(&cSlice_UsdFeisW, 1, -1);
  numBytes += cVar_init_f(&cVar_AhLOVB43, 0.313f);
  numBytes += cBinop_init(&cBinop_ktri6zAL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_iOzexMJ2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UJP8MifW, 0.0f);
  numBytes += cVar_init_f(&cVar_bNxXDaXm, 1337.0f);
  numBytes += cVar_init_f(&cVar_3lWMNZEQ, 0.3f);
  numBytes += cBinop_init(&cBinop_k25AO28z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2huzjHUe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sixQoTsp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fkwqnt4K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bcC48fQE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XNWqFrWC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xTsqBeaC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sJSjQL9o, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EnnvoJnI, 0.0f);
  numBytes += cVar_init_f(&cVar_gXFroO3j, 1337.0f);
  numBytes += cVar_init_f(&cVar_rVDqezGM, 0.313f);
  numBytes += cBinop_init(&cBinop_9DWwcIA7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q1uFYBNM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LOvzlw31, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ji1feV3V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gUcrJCXU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WXj9Zq45, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FQ1CpjvT, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EiSMgiQ2, 0.0f);
  numBytes += cVar_init_f(&cVar_Bq772Thi, 1037.0f);
  numBytes += cVar_init_f(&cVar_GWVQVuqv, 0.4f);
  numBytes += cBinop_init(&cBinop_WT31yBlR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6bQaP2Gr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WTfmqs7s, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1hI5sqWV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1LXoTeUI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MXsE6FLw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_dtMLzaxb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UDuDg0qb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6sS7HCQd, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_m7CH5J0K, 1, -1);
  numBytes += cVar_init_f(&cVar_xoHIX5RN, 1337.0f);
  numBytes += cVar_init_f(&cVar_lk8Dv7Up, 0.0f);
  numBytes += cIf_init(&cIf_gUIDwp12, false);
  numBytes += cIf_init(&cIf_JIuWQNkI, false);
  numBytes += cBinop_init(&cBinop_cIU01Oqr, 0.0f); // __pow
  numBytes += cIf_init(&cIf_SoZlfIn3, false);
  numBytes += cBinop_init(&cBinop_GzxqKMNG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_UEqNsaGj, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jNVBotPC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_1bfdHqvG, 0.0f);
  numBytes += cIf_init(&cIf_jLluDBHm, false);
  numBytes += cIf_init(&cIf_S6IKDpeO, false);
  numBytes += cBinop_init(&cBinop_7ufLefn4, 0.0f); // __pow
  numBytes += cIf_init(&cIf_kwU45YHf, false);
  numBytes += cBinop_init(&cBinop_0stDYXZY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PPOmDfYp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_HpzuTlCC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_fG2p4jWE, 0.0f);
  numBytes += cIf_init(&cIf_pSf73w9v, false);
  numBytes += cIf_init(&cIf_wvKy3GyI, false);
  numBytes += cBinop_init(&cBinop_uu7k9Afw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_SZvUDKKZ, false);
  numBytes += cBinop_init(&cBinop_YlQ1Ev7w, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_CQoCvyej, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_aCUk2gGB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_sjqDCwyk, false);
  numBytes += cSlice_init(&cSlice_r7G9OmTi, 1, -1);
  numBytes += cVar_init_f(&cVar_LC0LFcCq, 0.0f);
  numBytes += cSlice_init(&cSlice_v14ZHExI, 1, -1);
  numBytes += cVar_init_f(&cVar_JkhhBQzJ, 0.0f);
  numBytes += cSlice_init(&cSlice_GpZTugdm, 1, -1);
  numBytes += cVar_init_f(&cVar_Ln5UaYeY, 0.0f);
  numBytes += cSlice_init(&cSlice_UFY6DiFN, 1, -1);
  numBytes += cVar_init_f(&cVar_96JDEnLR, 0.313f);
  numBytes += cBinop_init(&cBinop_gdB03Xwz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_3CnrEN6a, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Znk8AoRK, 0.0f);
  numBytes += cVar_init_f(&cVar_Of3HMZJw, 1337.0f);
  numBytes += cVar_init_f(&cVar_x2Wpml3v, 0.3f);
  numBytes += cBinop_init(&cBinop_ggwqqxZY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_09TcSPzk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FaLhFBvN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L2MPA5Ot, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_b1RpTOxk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dBmTYW82, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Um7fw3rA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qLPwq1m8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bu3aTm6g, 0.0f);
  numBytes += cVar_init_f(&cVar_NVrdo6vE, 1337.0f);
  numBytes += cVar_init_f(&cVar_w0RiZ5i6, 0.313f);
  numBytes += cBinop_init(&cBinop_WpCBU9Z6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d9a01TSj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ouoJTSC0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U95FpkqK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ow2l8Nzy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E2OKXLYJ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_0p07kJ2d, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Vp0X25tg, 0.0f);
  numBytes += cVar_init_f(&cVar_88Kz8VCu, 1037.0f);
  numBytes += cVar_init_f(&cVar_nM25BPco, 0.4f);
  numBytes += cBinop_init(&cBinop_tm4tSbzC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UU47BoiS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bOEfhDRc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hItxXhbp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rw0ybWSG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xHwt8tAD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_thl23ZGW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RANnAcef, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DJyXn6JK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fosY6X2T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KtK32VLp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_alyJcKR4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IDWwfouK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8A2HrBLB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XHHpa2sx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_UNWKaUzO, 5705.6f);
  numBytes += cVar_init_f(&cVar_iSyyWy2b, 313.3f);
  numBytes += cBinop_init(&cBinop_1DU3KUPp, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_KyDdnmAL, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_DtiLfzMR, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S1Ow8DPe_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rgjLGeJH_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KvdHO3L8_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pDsZFDmS_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uqo8JZAT_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KCpK9nhQ_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dsrqBP5c_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kbWfoeVc_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0HasJXFI_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gxup8dEF_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MuEqYNex_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_liR2ah1H_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wpoSlajG_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PUj6gwDf_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uGdhUZ07_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d1y5ieAY_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w7J2snC0_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yjRkCfcj_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gEFhxnYf_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gSbFEUqN_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nLIXptl4_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cZRZtS8g_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zxXmdTS0_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e139hu6v_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BQx0EPUT_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MaqjcbS8_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X8IFh7PB_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RLLRX8FE_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K9LI2W3X_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qVHUfY03_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5gO3Z5vh_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YrYMUJfu_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lTDA2wbd_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_B02kDnM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mihWz2Ny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_kupL5ZNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dEkiGv8O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Kh7T4Mj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5tvp47b3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_QD0fnlxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dKq24g4S_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WvBPJqJQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wY787swj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BMk0EyGI_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_DtxM995T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZfuN1A1q, 0, m, &cSlice_ZfuN1A1q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dvUqKbro_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ZfuN1A1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jmXEkjiC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jmXEkjiC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_FraufON4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jmXEkjiC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_jmXEkjiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dsrqBP5c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_o84dhwz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WwWqSMV1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LdGZxkel, 0, m, &cIf_LdGZxkel_sendMessage);
}

void Heavy_WSTD_EQ::cIf_LdGZxkel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_v7BAyZOZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_Qc5Itmwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EaKlUNLl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_wz0GzwZW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_T6RUWrFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GzvztlVJ, HV_BINOP_POW, 0, m, &cBinop_GzvztlVJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GzvztlVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8N36bO20, 0, m, &cIf_8N36bO20_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZOaxxgaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_81iKKp03_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NzZmOzEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qc5Itmwv, 0, m, &cIf_Qc5Itmwv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lh15301Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fjyDGJq1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fjyDGJq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qc5Itmwv, 1, m, &cIf_Qc5Itmwv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wz0GzwZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZOaxxgaO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EaKlUNLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8N36bO20, 0, m, &cIf_8N36bO20_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_81iKKp03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GzvztlVJ, HV_BINOP_POW, 1, m, &cBinop_GzvztlVJ_sendMessage);
  cMsg_T6RUWrFn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_8N36bO20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dtMLzaxb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_WwWqSMV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LdGZxkel, 1, m, &cIf_LdGZxkel_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v7BAyZOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eB6Np7cD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eB6Np7cD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VI2HWIYJ, HV_BINOP_EQ, 1, m, &cBinop_VI2HWIYJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Xz0fDshV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6fJUjKZ, HV_BINOP_ADD, 0, m, &cBinop_M6fJUjKZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M6fJUjKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lh15301Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NzZmOzEQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eB6Np7cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8N36bO20, 1, m, &cIf_8N36bO20_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VI2HWIYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MSLbqH2T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_MSLbqH2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dtMLzaxb, m);
}

void Heavy_WSTD_EQ::cCast_35vNTDmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o84dhwz2, 0, m, &cVar_o84dhwz2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EANXfzGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xz0fDshV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_nOTuuhwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6fJUjKZ, HV_BINOP_ADD, 1, m, &cBinop_M6fJUjKZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eB6Np7cD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eB6Np7cD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VI2HWIYJ, HV_BINOP_EQ, 0, m, &cBinop_VI2HWIYJ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_uvTKxmKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_v45deRtN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_HVeVlllh, 0, m, &cIf_HVeVlllh_sendMessage);
}

void Heavy_WSTD_EQ::cIf_HVeVlllh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Dp6iFCqR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_yYzslIhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QNhxeGlb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_syAxWpbx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_If8FbLZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wA7o8lZa, HV_BINOP_POW, 0, m, &cBinop_wA7o8lZa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wA7o8lZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hSIXuEeM, 0, m, &cIf_hSIXuEeM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zt4e3yYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_PD9sEnIK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3qCHxlaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RS6BeWsp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IIrQBFoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yYzslIhS, 0, m, &cIf_yYzslIhS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RS6BeWsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yYzslIhS, 1, m, &cIf_yYzslIhS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_syAxWpbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zt4e3yYJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_QNhxeGlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hSIXuEeM, 0, m, &cIf_hSIXuEeM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PD9sEnIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wA7o8lZa, HV_BINOP_POW, 1, m, &cBinop_wA7o8lZa_sendMessage);
  cMsg_If8FbLZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_hSIXuEeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Y9Qb9ZI8_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_reLVNsX4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1ZDSSOzj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_v45deRtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HVeVlllh, 1, m, &cIf_HVeVlllh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Dp6iFCqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8f4JWSQf, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8f4JWSQf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_egZ4FOZy, HV_BINOP_EQ, 1, m, &cBinop_egZ4FOZy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JpfkD0ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IB7rbEVW, HV_BINOP_ADD, 0, m, &cBinop_IB7rbEVW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IB7rbEVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3qCHxlaj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IIrQBFoy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8f4JWSQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hSIXuEeM, 1, m, &cIf_hSIXuEeM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_egZ4FOZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FFqJ7qsH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_FFqJ7qsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Y9Qb9ZI8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_reLVNsX4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1ZDSSOzj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LihRTbh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IB7rbEVW, HV_BINOP_ADD, 1, m, &cBinop_IB7rbEVW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8f4JWSQf, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8f4JWSQf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_egZ4FOZy, HV_BINOP_EQ, 0, m, &cBinop_egZ4FOZy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IymdAW44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uvTKxmKH, 0, m, &cVar_uvTKxmKH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WFHooBTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JpfkD0ho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gXZRLooR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_v1pgGm9B_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_UzdUYKWm, 0, m, &cIf_UzdUYKWm_sendMessage);
}

void Heavy_WSTD_EQ::cIf_UzdUYKWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5gnePUJA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_MKIa2PAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SbKuhVqy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_sWTyDNix_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_l4eKokoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_foF2mwD8, HV_BINOP_POW, 0, m, &cBinop_foF2mwD8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_foF2mwD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ez8p4TUQ, 0, m, &cIf_ez8p4TUQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nTS1VTBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lTfIpzJH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cp7kGxW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKIa2PAU, 0, m, &cIf_MKIa2PAU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2bJc0ob8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u5q7kxL6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u5q7kxL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKIa2PAU, 1, m, &cIf_MKIa2PAU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sWTyDNix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_nTS1VTBk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SbKuhVqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ez8p4TUQ, 0, m, &cIf_ez8p4TUQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lTfIpzJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_foF2mwD8, HV_BINOP_POW, 1, m, &cBinop_foF2mwD8_sendMessage);
  cMsg_l4eKokoS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_ez8p4TUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6sS7HCQd, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_v1pgGm9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UzdUYKWm, 1, m, &cIf_UzdUYKWm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5gnePUJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LaqUTtQX, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LaqUTtQX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lpa1ujXP, HV_BINOP_EQ, 1, m, &cBinop_lpa1ujXP_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_v5K6YvqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y51sSl3Q, HV_BINOP_ADD, 0, m, &cBinop_y51sSl3Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_y51sSl3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2bJc0ob8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cp7kGxW0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LaqUTtQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ez8p4TUQ, 1, m, &cIf_ez8p4TUQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lpa1ujXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ge8KfDxs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ge8KfDxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6sS7HCQd, m);
}

void Heavy_WSTD_EQ::cCast_cEoYqLPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v5K6YvqM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Z1HC7NhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y51sSl3Q, HV_BINOP_ADD, 1, m, &cBinop_y51sSl3Q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LaqUTtQX, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LaqUTtQX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lpa1ujXP, HV_BINOP_EQ, 0, m, &cBinop_lpa1ujXP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HqMqLfvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gXZRLooR, 0, m, &cVar_gXZRLooR_sendMessage);
}

void Heavy_WSTD_EQ::cIf_2tLEcfI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_UDuDg0qb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_MjHFKOLj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S4Z3sQQC, 0, m, &cSlice_S4Z3sQQC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CUsdvINZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_S4Z3sQQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xQ1E9K4t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xQ1E9K4t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_91huKjHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xQ1E9K4t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_xQ1E9K4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uqo8JZAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_CUsdvINZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aEBHUHTY, 0, m, &cSlice_aEBHUHTY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DtxM995T_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_aEBHUHTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t4X1ohn4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t4X1ohn4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_F353yiLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t4X1ohn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_t4X1ohn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0HasJXFI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_dvUqKbro_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g9CUwuX3, 0, m, &cSlice_g9CUwuX3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mpbkyoEg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_g9CUwuX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hgkkNfcr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hgkkNfcr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_uOHJ3PVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hgkkNfcr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hgkkNfcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KCpK9nhQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_mpbkyoEg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UsdFeisW, 0, m, &cSlice_UsdFeisW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_UsdFeisW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_x9hODt5X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_x9hODt5X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_AhLOVB43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x9hODt5X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_x9hODt5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kbWfoeVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_LbbR2xvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bZhG2mJA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ch1ZkhbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EXpbeNjS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_XW5h9lyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JldsxYdV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dGvFvcl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gvkiHgnT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WLBaw19c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qBf0oTQr, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5R8oGpTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OUeQETwK_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_OUeQETwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktri6zAL, HV_BINOP_DIVIDE, 1, m, &cBinop_ktri6zAL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tezi3dxq_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_p0PZdxW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_T3xYGnPr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yiEJGHJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_p0PZdxW9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_T3xYGnPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktri6zAL, HV_BINOP_DIVIDE, 0, m, &cBinop_ktri6zAL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tezi3dxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yiEJGHJJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ktri6zAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iOzexMJ2, HV_BINOP_MULTIPLY, 1, m, &cBinop_iOzexMJ2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iOzexMJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5P3Ca2yX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IuYhRZ9e_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_OWtPlHka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oJLJjhRG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_DBlahyUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VndM0Hc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Mc8hkIz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NkpdZHjv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NkpdZHjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iOzexMJ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_iOzexMJ2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xBrbkPKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Z6542Kns_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z6542Kns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WTzoH4iJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yydL0GVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UJP8MifW, 1, m, &cVar_UJP8MifW_sendMessage);
}

void Heavy_WSTD_EQ::cVar_UJP8MifW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nVk5O6Se_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zrNthIae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2huzjHUe, HV_BINOP_MULTIPLY, 1, m, &cBinop_2huzjHUe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qxo4VQJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zrNthIae_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pTScQVsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_R5dF1UEY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R5dF1UEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sixQoTsp, HV_BINOP_MULTIPLY, 1, m, &cBinop_sixQoTsp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VEIMh0Qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkwqnt4K, HV_BINOP_MULTIPLY, 1, m, &cBinop_fkwqnt4K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EXB3Pnll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VEIMh0Qy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RRjUJNxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bcC48fQE, HV_BINOP_MULTIPLY, 1, m, &cBinop_bcC48fQE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8yivIDb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XZWVyixw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XZWVyixw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XNWqFrWC, HV_BINOP_MULTIPLY, 1, m, &cBinop_XNWqFrWC_sendMessage);
}

void Heavy_WSTD_EQ::cVar_bNxXDaXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8vXud8GP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Mc8hkIz8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vNYR8Pxa_sendMessage);
}

void Heavy_WSTD_EQ::cVar_3lWMNZEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xBrbkPKS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IuYhRZ9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_DBlahyUT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5P3Ca2yX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_OWtPlHka_sendMessage);
}

void Heavy_WSTD_EQ::cSend_oJLJjhRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_liR2ah1H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VndM0Hc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MuEqYNex_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_tFokLy7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gxup8dEF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_WTzoH4iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_b1T2mQ2C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b1T2mQ2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k25AO28z, HV_BINOP_MULTIPLY, 1, m, &cBinop_k25AO28z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k25AO28z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KXKjVmYO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KXKjVmYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tFokLy7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nVk5O6Se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_S5YdHR43_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S5YdHR43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VS4OvHXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kkz9bCYn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_23bhmgqZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2UgSHRhF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AD3FmuwG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iVehMqtz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2huzjHUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LbbR2xvP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_sixQoTsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ch1ZkhbI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fkwqnt4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XW5h9lyE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bcC48fQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dGvFvcl1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XNWqFrWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WLBaw19c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_1lMKybsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3lWMNZEQ, 1, m, &cVar_3lWMNZEQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BZ9ZsGA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bNxXDaXm, 0, m, &cVar_bNxXDaXm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2UgSHRhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkwqnt4K, HV_BINOP_MULTIPLY, 0, m, &cBinop_fkwqnt4K_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VS4OvHXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_iVehMqtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2huzjHUe, HV_BINOP_MULTIPLY, 0, m, &cBinop_2huzjHUe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_23bhmgqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bcC48fQE, HV_BINOP_MULTIPLY, 0, m, &cBinop_bcC48fQE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AD3FmuwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sixQoTsp, HV_BINOP_MULTIPLY, 0, m, &cBinop_sixQoTsp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kkz9bCYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XNWqFrWC, HV_BINOP_MULTIPLY, 0, m, &cBinop_XNWqFrWC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vNYR8Pxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UJP8MifW, 0, m, &cVar_UJP8MifW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8vXud8GP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3lWMNZEQ, 0, m, &cVar_3lWMNZEQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6VaFE7wK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ydtI3lBz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_f664AqMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GGFk8OIR, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bAWpkHfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LBKTejcO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_y3KwJ442_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L0E8zzyz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7FrBoUPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lzorB6Lb_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_lzorB6Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTsqBeaC, HV_BINOP_DIVIDE, 1, m, &cBinop_xTsqBeaC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cpWfE282_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_rTKjaQ2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_YWwoqI1J_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Z8YDelJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rTKjaQ2y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YWwoqI1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTsqBeaC, HV_BINOP_DIVIDE, 0, m, &cBinop_xTsqBeaC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cpWfE282_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z8YDelJi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xTsqBeaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJSjQL9o, HV_BINOP_MULTIPLY, 1, m, &cBinop_sJSjQL9o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sJSjQL9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FRxstFqg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LHtKGy8n_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_idSs7PtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZqK0WoBO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_U6Ur7ufE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VDuuv1vm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HWztPTG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_S4kCTrxF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S4kCTrxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJSjQL9o, HV_BINOP_MULTIPLY, 0, m, &cBinop_sJSjQL9o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VQxhafzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_2lJw3Vf2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2lJw3Vf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5U7qPlbW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GH0yqhZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LOvzlw31, HV_BINOP_MULTIPLY, 1, m, &cBinop_LOvzlw31_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KYWzJlwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EnnvoJnI, 1, m, &cVar_EnnvoJnI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_o5nQAniK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ji1feV3V, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ji1feV3V_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SH2pnKe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Jn4lB4Hk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Jn4lB4Hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gUcrJCXU, HV_BINOP_MULTIPLY, 1, m, &cBinop_gUcrJCXU_sendMessage);
}

void Heavy_WSTD_EQ::cVar_EnnvoJnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Td4mUPJm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gXFroO3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nb3Vx8EJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HWztPTG2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rWPGZgoh_sendMessage);
}

void Heavy_WSTD_EQ::cVar_rVDqezGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VQxhafzM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FRxstFqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_idSs7PtF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LHtKGy8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_U6Ur7ufE_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ZqK0WoBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uGdhUZ07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VDuuv1vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PUj6gwDf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fbxkKNZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wpoSlajG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_5U7qPlbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HfsH6KiC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HfsH6KiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9DWwcIA7, HV_BINOP_MULTIPLY, 1, m, &cBinop_9DWwcIA7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9DWwcIA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_95Wn1MbV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_95Wn1MbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fbxkKNZA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Td4mUPJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QdTphDb6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QdTphDb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4D2zXW0F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SYz2HMQy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aCbxErjU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pSJfEhnF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q1uFYBNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6VaFE7wK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_LOvzlw31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f664AqMh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ji1feV3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bAWpkHfD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gUcrJCXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y3KwJ442_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_zDlWRfsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gXFroO3j, 0, m, &cVar_gXFroO3j_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AqMhtyBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rVDqezGM, 1, m, &cVar_rVDqezGM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rWPGZgoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EnnvoJnI, 0, m, &cVar_EnnvoJnI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nb3Vx8EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rVDqezGM, 0, m, &cVar_rVDqezGM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4D2zXW0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gUcrJCXU, HV_BINOP_MULTIPLY, 0, m, &cBinop_gUcrJCXU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aCbxErjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LOvzlw31, HV_BINOP_MULTIPLY, 0, m, &cBinop_LOvzlw31_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SYz2HMQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ji1feV3V, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ji1feV3V_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pSJfEhnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q1uFYBNM, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q1uFYBNM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ELxblgYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NQaBwCV9, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_6aIpVHso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rXPmsFRb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_v1rNZkqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wFscdfRp, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4Qq4aXeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rKcKjTrb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_tdv9dtdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vL8QbiQ4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_VfvlHgSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Dp6gpErM_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Dp6gpErM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WXj9Zq45, HV_BINOP_DIVIDE, 1, m, &cBinop_WXj9Zq45_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vi1iDX4P_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FavYB49q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_bsbe0H8p_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FoJ2QDOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FavYB49q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bsbe0H8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WXj9Zq45, HV_BINOP_DIVIDE, 0, m, &cBinop_WXj9Zq45_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Vi1iDX4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FoJ2QDOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WXj9Zq45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQ1CpjvT, HV_BINOP_MULTIPLY, 1, m, &cBinop_FQ1CpjvT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FQ1CpjvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ovo3k603_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jxBuq2Ad_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_uC8D1aqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bBl2phV6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_vfUMZj4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZF31yZhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_P0zo5HQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_4jvVFFPW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4jvVFFPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQ1CpjvT, HV_BINOP_MULTIPLY, 0, m, &cBinop_FQ1CpjvT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LsI1XXGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9c8vxUxV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9c8vxUxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2IwhZViW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iqjAMarm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6bQaP2Gr, HV_BINOP_MULTIPLY, 1, m, &cBinop_6bQaP2Gr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_QZx6EJQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5Ys8kgzk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5Ys8kgzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iqjAMarm_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7ac6qU1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_597WUn2k_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_597WUn2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WTfmqs7s, HV_BINOP_MULTIPLY, 1, m, &cBinop_WTfmqs7s_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Lh2gmUB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1hI5sqWV, HV_BINOP_MULTIPLY, 1, m, &cBinop_1hI5sqWV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_NhJdrkPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gKOtm7xK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gKOtm7xK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Lh2gmUB3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JVeIIaIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EiSMgiQ2, 1, m, &cVar_EiSMgiQ2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rw3UiP7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LXoTeUI, HV_BINOP_MULTIPLY, 1, m, &cBinop_1LXoTeUI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EjCNm4dA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MRIpZYM7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MRIpZYM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MXsE6FLw, HV_BINOP_MULTIPLY, 1, m, &cBinop_MXsE6FLw_sendMessage);
}

void Heavy_WSTD_EQ::cVar_EiSMgiQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MWPLCqEw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Bq772Thi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Ey08stm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_P0zo5HQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyOM4WCz_sendMessage);
}

void Heavy_WSTD_EQ::cVar_GWVQVuqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_LsI1XXGG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ovo3k603_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uC8D1aqz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jxBuq2Ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_vfUMZj4M_sendMessage);
}

void Heavy_WSTD_EQ::cSend_bBl2phV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yjRkCfcj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ZF31yZhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_w7J2snC0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fut3nUYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_d1y5ieAY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_2IwhZViW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IPY2cEXe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IPY2cEXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WT31yBlR, HV_BINOP_MULTIPLY, 1, m, &cBinop_WT31yBlR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WT31yBlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dFWfV2i6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dFWfV2i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fut3nUYc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_MWPLCqEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_53T4YhiS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_53T4YhiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yS25lm8v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8AZno94j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DvriYJC3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ziMz387C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8gEJnTUP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_459jDDDR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6bQaP2Gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ELxblgYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WTfmqs7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aIpVHso_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1hI5sqWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v1rNZkqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1LXoTeUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Qq4aXeU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MXsE6FLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tdv9dtdG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_aHOlwhaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bq772Thi, 0, m, &cVar_Bq772Thi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nAVAuTUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GWVQVuqv, 1, m, &cVar_GWVQVuqv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_459jDDDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6bQaP2Gr, HV_BINOP_MULTIPLY, 0, m, &cBinop_6bQaP2Gr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DvriYJC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LXoTeUI, HV_BINOP_MULTIPLY, 0, m, &cBinop_1LXoTeUI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8gEJnTUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WTfmqs7s, HV_BINOP_MULTIPLY, 0, m, &cBinop_WTfmqs7s_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8AZno94j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MXsE6FLw, HV_BINOP_MULTIPLY, 0, m, &cBinop_MXsE6FLw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ziMz387C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1hI5sqWV, HV_BINOP_MULTIPLY, 0, m, &cBinop_1hI5sqWV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yS25lm8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_2Ey08stm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GWVQVuqv, 0, m, &cVar_GWVQVuqv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iyOM4WCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EiSMgiQ2, 0, m, &cVar_EiSMgiQ2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Y9Qb9ZI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2tLEcfI3, 1, m, &cIf_2tLEcfI3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vbaEMq1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UDuDg0qb, m);
}

void Heavy_WSTD_EQ::cBinop_reLVNsX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vbaEMq1b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1ZDSSOzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2tLEcfI3, 0, m, &cIf_2tLEcfI3_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_KSgLWzkn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_m7CH5J0K, 0, m, &cSlice_m7CH5J0K_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NoLbiOLa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_m7CH5J0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hc9awpmN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hc9awpmN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_xoHIX5RN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hc9awpmN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Hc9awpmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nLIXptl4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_lk8Dv7Up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jargmT64_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gUIDwp12, 0, m, &cIf_gUIDwp12_sendMessage);
}

void Heavy_WSTD_EQ::cIf_gUIDwp12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Hq6AkW9I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_JIuWQNkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_n5gewDRZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_oQTg0DOW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_zTW3dSZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIU01Oqr, HV_BINOP_POW, 0, m, &cBinop_cIU01Oqr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cIU01Oqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SoZlfIn3, 0, m, &cIf_SoZlfIn3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v6bDq5Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tzqwMG9Y_sendMessage);
}

void Heavy_WSTD_EQ::cCast_d7LCWMVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JIuWQNkI, 0, m, &cIf_JIuWQNkI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8xt3j23O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HKo4zdFP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HKo4zdFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JIuWQNkI, 1, m, &cIf_JIuWQNkI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oQTg0DOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_v6bDq5Wj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_n5gewDRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SoZlfIn3, 0, m, &cIf_SoZlfIn3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tzqwMG9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIU01Oqr, HV_BINOP_POW, 1, m, &cBinop_cIU01Oqr_sendMessage);
  cMsg_zTW3dSZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_SoZlfIn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_thl23ZGW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_jargmT64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gUIDwp12, 1, m, &cIf_gUIDwp12_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hq6AkW9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEqNsaGj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UEqNsaGj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jNVBotPC, HV_BINOP_EQ, 1, m, &cBinop_jNVBotPC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zB75D4O5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GzxqKMNG, HV_BINOP_ADD, 0, m, &cBinop_GzxqKMNG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GzxqKMNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8xt3j23O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d7LCWMVh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UEqNsaGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SoZlfIn3, 1, m, &cIf_SoZlfIn3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jNVBotPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jx8K2zBh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_jx8K2zBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_thl23ZGW, m);
}

void Heavy_WSTD_EQ::cCast_o5moYQsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zB75D4O5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_9Lengetd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GzxqKMNG, HV_BINOP_ADD, 1, m, &cBinop_GzxqKMNG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEqNsaGj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UEqNsaGj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jNVBotPC, HV_BINOP_EQ, 0, m, &cBinop_jNVBotPC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t2XUdO48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lk8Dv7Up, 0, m, &cVar_lk8Dv7Up_sendMessage);
}

void Heavy_WSTD_EQ::cVar_1bfdHqvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kqsT0gEK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jLluDBHm, 0, m, &cIf_jLluDBHm_sendMessage);
}

void Heavy_WSTD_EQ::cIf_jLluDBHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LHYg9g8l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_S6IKDpeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HgkqjnKA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_yx9K5409_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_EGcsyQ1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ufLefn4, HV_BINOP_POW, 0, m, &cBinop_7ufLefn4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7ufLefn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kwU45YHf, 0, m, &cIf_kwU45YHf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CP7TY1nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YOcY86EA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6IbLkEdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F3WqyBk2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iKLnlw80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S6IKDpeO, 0, m, &cIf_S6IKDpeO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F3WqyBk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S6IKDpeO, 1, m, &cIf_S6IKDpeO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yx9K5409_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_CP7TY1nf_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HgkqjnKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kwU45YHf, 0, m, &cIf_kwU45YHf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YOcY86EA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ufLefn4, HV_BINOP_POW, 1, m, &cBinop_7ufLefn4_sendMessage);
  cMsg_EGcsyQ1M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_kwU45YHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XZCaRxWV_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YkhygAIn_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_aMVQXFQS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_kqsT0gEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jLluDBHm, 1, m, &cIf_jLluDBHm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LHYg9g8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPOmDfYp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PPOmDfYp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HpzuTlCC, HV_BINOP_EQ, 1, m, &cBinop_HpzuTlCC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TJpatW2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0stDYXZY, HV_BINOP_ADD, 0, m, &cBinop_0stDYXZY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0stDYXZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6IbLkEdT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iKLnlw80_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PPOmDfYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kwU45YHf, 1, m, &cIf_kwU45YHf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HpzuTlCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zyCNqE6U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_zyCNqE6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XZCaRxWV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YkhygAIn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_aMVQXFQS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sTZAsGkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1bfdHqvG, 0, m, &cVar_1bfdHqvG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kHB9iAO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJpatW2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_H2W34SNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0stDYXZY, HV_BINOP_ADD, 1, m, &cBinop_0stDYXZY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPOmDfYp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PPOmDfYp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HpzuTlCC, HV_BINOP_EQ, 0, m, &cBinop_HpzuTlCC_sendMessage);
}

void Heavy_WSTD_EQ::cVar_fG2p4jWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kPi3F36n_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_pSf73w9v, 0, m, &cIf_pSf73w9v_sendMessage);
}

void Heavy_WSTD_EQ::cIf_pSf73w9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5uKht8WH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_wvKy3GyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3XNJlYFZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Crfo4d9n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_G6eJQVau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uu7k9Afw, HV_BINOP_POW, 0, m, &cBinop_uu7k9Afw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uu7k9Afw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SZvUDKKZ, 0, m, &cIf_SZvUDKKZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NB23Ypyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_VqKc3mx5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4wCNoHq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wvKy3GyI, 0, m, &cIf_wvKy3GyI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_X2Q0lj1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QV0WSxzl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QV0WSxzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wvKy3GyI, 1, m, &cIf_wvKy3GyI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Crfo4d9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_NB23Ypyw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3XNJlYFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SZvUDKKZ, 0, m, &cIf_SZvUDKKZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VqKc3mx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uu7k9Afw, HV_BINOP_POW, 1, m, &cBinop_uu7k9Afw_sendMessage);
  cMsg_G6eJQVau_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_SZvUDKKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_DJyXn6JK, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_kPi3F36n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pSf73w9v, 1, m, &cIf_pSf73w9v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5uKht8WH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQoCvyej, HV_BINOP_GREATER_THAN, 1, m, &cBinop_CQoCvyej_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aCUk2gGB, HV_BINOP_EQ, 1, m, &cBinop_aCUk2gGB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZnmGfHmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlQ1Ev7w, HV_BINOP_ADD, 0, m, &cBinop_YlQ1Ev7w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YlQ1Ev7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X2Q0lj1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4wCNoHq2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CQoCvyej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SZvUDKKZ, 1, m, &cIf_SZvUDKKZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aCUk2gGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ivj6cGDC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Ivj6cGDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_DJyXn6JK, m);
}

void Heavy_WSTD_EQ::cCast_LhS2nO1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fG2p4jWE, 0, m, &cVar_fG2p4jWE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_f8M7DUZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZnmGfHmg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_oh8N81eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlQ1Ev7w, HV_BINOP_ADD, 1, m, &cBinop_YlQ1Ev7w_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQoCvyej, HV_BINOP_GREATER_THAN, 0, m, &cBinop_CQoCvyej_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aCUk2gGB, HV_BINOP_EQ, 0, m, &cBinop_aCUk2gGB_sendMessage);
}

void Heavy_WSTD_EQ::cIf_sjqDCwyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_RANnAcef, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_WF8NFTRT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r7G9OmTi, 0, m, &cSlice_r7G9OmTi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kzHD4kvk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_r7G9OmTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rtbWVO1q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rtbWVO1q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_LC0LFcCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rtbWVO1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_rtbWVO1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gEFhxnYf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_kzHD4kvk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v14ZHExI, 0, m, &cSlice_v14ZHExI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KSgLWzkn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_v14ZHExI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sCbEbsYh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sCbEbsYh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_JkhhBQzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sCbEbsYh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_sCbEbsYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zxXmdTS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_NoLbiOLa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GpZTugdm, 0, m, &cSlice_GpZTugdm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Fn6fX37q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_GpZTugdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FVLeIBIA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FVLeIBIA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Ln5UaYeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FVLeIBIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_FVLeIBIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gSbFEUqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_Fn6fX37q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UFY6DiFN, 0, m, &cSlice_UFY6DiFN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_UFY6DiFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PuXuENec_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PuXuENec_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_96JDEnLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PuXuENec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_PuXuENec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cZRZtS8g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_V7ruKEq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mLmYYCjb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uyFiTOj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t1v4tUSr, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pfPkWbyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yMlU0Hot, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rzifKTuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1p5IABSn, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DlzHGIvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0iIXP59a, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FuXrvbow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sAU2u3Th_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_sAU2u3Th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdB03Xwz, HV_BINOP_DIVIDE, 1, m, &cBinop_gdB03Xwz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5W8tmLWC_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_nXnfIc9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_7W5cnJRj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uAeNvcG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nXnfIc9K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7W5cnJRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdB03Xwz, HV_BINOP_DIVIDE, 0, m, &cBinop_gdB03Xwz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5W8tmLWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uAeNvcG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gdB03Xwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3CnrEN6a, HV_BINOP_MULTIPLY, 1, m, &cBinop_3CnrEN6a_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3CnrEN6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YQhAo6Yh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XjTVObJr_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_sQNrVGJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_E3MYQoI1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_mdNI8LKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RC2udNtU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IxMfg24Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_OR48qgsx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OR48qgsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3CnrEN6a, HV_BINOP_MULTIPLY, 0, m, &cBinop_3CnrEN6a_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vTZygR7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_sOsxDkkb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sOsxDkkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u1SRLLP7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8MbuzBy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Znk8AoRK, 1, m, &cVar_Znk8AoRK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Znk8AoRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PUeEUuM5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pB7WPzSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_09TcSPzk, HV_BINOP_MULTIPLY, 1, m, &cBinop_09TcSPzk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4S5NXd2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pB7WPzSR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PwHGW5JU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JUPaadK8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JUPaadK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FaLhFBvN, HV_BINOP_MULTIPLY, 1, m, &cBinop_FaLhFBvN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mCGK9NWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2MPA5Ot, HV_BINOP_MULTIPLY, 1, m, &cBinop_L2MPA5Ot_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dcotGE5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mCGK9NWx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wFKe479g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b1RpTOxk, HV_BINOP_MULTIPLY, 1, m, &cBinop_b1RpTOxk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WFkV084U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LXSrepYs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LXSrepYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dBmTYW82, HV_BINOP_MULTIPLY, 1, m, &cBinop_dBmTYW82_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Of3HMZJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MsywQvCo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IxMfg24Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aQufCUHL_sendMessage);
}

void Heavy_WSTD_EQ::cVar_x2Wpml3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vTZygR7i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XjTVObJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_mdNI8LKr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YQhAo6Yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_sQNrVGJh_sendMessage);
}

void Heavy_WSTD_EQ::cSend_E3MYQoI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MaqjcbS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_RC2udNtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BQx0EPUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ssjO3lWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e139hu6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_u1SRLLP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BVU64ayu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BVU64ayu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ggwqqxZY, HV_BINOP_MULTIPLY, 1, m, &cBinop_ggwqqxZY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ggwqqxZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XKoUlQM7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XKoUlQM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ssjO3lWM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PUeEUuM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_q4uNqEL3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q4uNqEL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AW8WAPJy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9rkAgB2s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OZuOVKHv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yBVsY0bU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ABRNDj0h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f26fmPQo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_09TcSPzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V7ruKEq2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FaLhFBvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uyFiTOj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_L2MPA5Ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pfPkWbyP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_b1RpTOxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rzifKTuN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dBmTYW82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DlzHGIvt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_cw0VMUFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x2Wpml3v, 1, m, &cVar_x2Wpml3v_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QONX3xX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Of3HMZJw, 0, m, &cVar_Of3HMZJw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ABRNDj0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FaLhFBvN, HV_BINOP_MULTIPLY, 0, m, &cBinop_FaLhFBvN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9rkAgB2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dBmTYW82, HV_BINOP_MULTIPLY, 0, m, &cBinop_dBmTYW82_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yBVsY0bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2MPA5Ot, HV_BINOP_MULTIPLY, 0, m, &cBinop_L2MPA5Ot_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AW8WAPJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_f26fmPQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_09TcSPzk, HV_BINOP_MULTIPLY, 0, m, &cBinop_09TcSPzk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OZuOVKHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b1RpTOxk, HV_BINOP_MULTIPLY, 0, m, &cBinop_b1RpTOxk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aQufCUHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Znk8AoRK, 0, m, &cVar_Znk8AoRK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MsywQvCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x2Wpml3v, 0, m, &cVar_x2Wpml3v_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bgHHUrhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GlMVmWy3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_57NGpYOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QrTTpkCN, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Obek3tQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mYLjS90O, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SpHJLfaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5PZGh9zr, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_OFHglL23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3bZaLfda_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_3bZaLfda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Um7fw3rA, HV_BINOP_DIVIDE, 1, m, &cBinop_Um7fw3rA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p7wIE847_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_hOC71kti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Ah960XzM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tIPrVusk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hOC71kti_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ah960XzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Um7fw3rA, HV_BINOP_DIVIDE, 0, m, &cBinop_Um7fw3rA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_p7wIE847_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tIPrVusk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Um7fw3rA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qLPwq1m8, HV_BINOP_MULTIPLY, 1, m, &cBinop_qLPwq1m8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qLPwq1m8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yuYO82YY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sCdOlgUs_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_OQ1LwpmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ah0Y9Dar_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_1u3FDx1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WWaqqzWx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_41p560A1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_G0TMWKjG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G0TMWKjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qLPwq1m8, HV_BINOP_MULTIPLY, 0, m, &cBinop_qLPwq1m8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_P3TZPZB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9eAuU5ur_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9eAuU5ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1XcM1hlu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oJ67W1G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ouoJTSC0, HV_BINOP_MULTIPLY, 1, m, &cBinop_ouoJTSC0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qfilc8ST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bu3aTm6g, 1, m, &cVar_bu3aTm6g_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wo447MNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U95FpkqK, HV_BINOP_MULTIPLY, 1, m, &cBinop_U95FpkqK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_dyQOEUN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0eqw3F9f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0eqw3F9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ow2l8Nzy, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ow2l8Nzy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_bu3aTm6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZWPnGcy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_NVrdo6vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CNg2MFJP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_41p560A1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IiJ2n8z3_sendMessage);
}

void Heavy_WSTD_EQ::cVar_w0RiZ5i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_P3TZPZB7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sCdOlgUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_1u3FDx1s_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yuYO82YY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_OQ1LwpmC_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ah0Y9Dar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K9LI2W3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WWaqqzWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RLLRX8FE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_tOy1Pe9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X8IFh7PB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_1XcM1hlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AigADOjT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AigADOjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WpCBU9Z6, HV_BINOP_MULTIPLY, 1, m, &cBinop_WpCBU9Z6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WpCBU9Z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nkg7S1fN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nkg7S1fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tOy1Pe9S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_yZWPnGcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_feOoEzPm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_feOoEzPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WCrUAfIu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8WhvcZOn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lo5SZXGX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gv4Ydv3N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d9a01TSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bgHHUrhc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ouoJTSC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_57NGpYOV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_U95FpkqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Obek3tQD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ow2l8Nzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SpHJLfaa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_b733VE6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NVrdo6vE, 0, m, &cVar_NVrdo6vE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1uOwWS4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0RiZ5i6, 1, m, &cVar_w0RiZ5i6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IiJ2n8z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bu3aTm6g, 0, m, &cVar_bu3aTm6g_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CNg2MFJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0RiZ5i6, 0, m, &cVar_w0RiZ5i6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WCrUAfIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ow2l8Nzy, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ow2l8Nzy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lo5SZXGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ouoJTSC0, HV_BINOP_MULTIPLY, 0, m, &cBinop_ouoJTSC0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8WhvcZOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U95FpkqK, HV_BINOP_MULTIPLY, 0, m, &cBinop_U95FpkqK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Gv4Ydv3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9a01TSj, HV_BINOP_MULTIPLY, 0, m, &cBinop_d9a01TSj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_iVDMdKhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MD7JkkXP, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_H8LHjtYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rNc75q6f, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SkTnu0VN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tPCoPcpg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EyLoManG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9UES8ZTy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_PHfXrTr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yUrY0Y5O, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KX0emTIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pkCELeEZ_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_pkCELeEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E2OKXLYJ, HV_BINOP_DIVIDE, 1, m, &cBinop_E2OKXLYJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hBnQvDMa_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_gSrJ3cXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qXQzH9cD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wZtMpqGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_gSrJ3cXp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qXQzH9cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E2OKXLYJ, HV_BINOP_DIVIDE, 0, m, &cBinop_E2OKXLYJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hBnQvDMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wZtMpqGu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_E2OKXLYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0p07kJ2d, HV_BINOP_MULTIPLY, 1, m, &cBinop_0p07kJ2d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0p07kJ2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yPoZiRdJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MBmF1H0j_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_yaw43jsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q65ve7WP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_irISquyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HvLl8fO9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XhjI0sEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_csjakje6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_csjakje6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0p07kJ2d, HV_BINOP_MULTIPLY, 0, m, &cBinop_0p07kJ2d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BkoozgJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_jRrhxLYI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jRrhxLYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xxpyp15V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3zIVCVJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UU47BoiS, HV_BINOP_MULTIPLY, 1, m, &cBinop_UU47BoiS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GTeiMuMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p7GKO8CK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p7GKO8CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3zIVCVJo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EDJxla3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Y33WSTUc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Y33WSTUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOEfhDRc, HV_BINOP_MULTIPLY, 1, m, &cBinop_bOEfhDRc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SuLRPTgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hItxXhbp, HV_BINOP_MULTIPLY, 1, m, &cBinop_hItxXhbp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cfWCWgMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rDHzUp3f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rDHzUp3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SuLRPTgW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Cm8xcz3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vp0X25tg, 1, m, &cVar_Vp0X25tg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OQsyVDNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rw0ybWSG, HV_BINOP_MULTIPLY, 1, m, &cBinop_rw0ybWSG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2QMb4ITp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gDbMTrrl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gDbMTrrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xHwt8tAD, HV_BINOP_MULTIPLY, 1, m, &cBinop_xHwt8tAD_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Vp0X25tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ihrqmcV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_88Kz8VCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cV1Ca6Mg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XhjI0sEM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ihUZcZYv_sendMessage);
}

void Heavy_WSTD_EQ::cVar_nM25BPco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BkoozgJi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yPoZiRdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yaw43jsJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MBmF1H0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_irISquyE_sendMessage);
}

void Heavy_WSTD_EQ::cSend_q65ve7WP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YrYMUJfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_HvLl8fO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5gO3Z5vh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_uhJ6hlVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qVHUfY03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Xxpyp15V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9eEFHm0F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9eEFHm0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tm4tSbzC, HV_BINOP_MULTIPLY, 1, m, &cBinop_tm4tSbzC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tm4tSbzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aYk8TsSj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aYk8TsSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uhJ6hlVC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_5ihrqmcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GKURRR9j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GKURRR9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bEy0wDmL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0IV1tdDt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wp0SBvjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vlIjCzJj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fkfJV1M1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CKwmCi80_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UU47BoiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iVDMdKhV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bOEfhDRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H8LHjtYC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hItxXhbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SkTnu0VN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rw0ybWSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EyLoManG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xHwt8tAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PHfXrTr6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_h5Xm1LUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_88Kz8VCu, 0, m, &cVar_88Kz8VCu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xnLe1Ee4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nM25BPco, 1, m, &cVar_nM25BPco_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fkfJV1M1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOEfhDRc, HV_BINOP_MULTIPLY, 0, m, &cBinop_bOEfhDRc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Wp0SBvjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rw0ybWSG, HV_BINOP_MULTIPLY, 0, m, &cBinop_rw0ybWSG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vlIjCzJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hItxXhbp, HV_BINOP_MULTIPLY, 0, m, &cBinop_hItxXhbp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0IV1tdDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xHwt8tAD, HV_BINOP_MULTIPLY, 0, m, &cBinop_xHwt8tAD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CKwmCi80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UU47BoiS, HV_BINOP_MULTIPLY, 0, m, &cBinop_UU47BoiS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bEy0wDmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_cV1Ca6Mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nM25BPco, 0, m, &cVar_nM25BPco_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ihUZcZYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vp0X25tg, 0, m, &cVar_Vp0X25tg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XZCaRxWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sjqDCwyk, 1, m, &cIf_sjqDCwyk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3O2fa3fK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RANnAcef, m);
}

void Heavy_WSTD_EQ::cBinop_YkhygAIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3O2fa3fK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_aMVQXFQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sjqDCwyk, 0, m, &cIf_sjqDCwyk_sendMessage);
}

void Heavy_WSTD_EQ::cVar_UNWKaUzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KyDdnmAL, HV_BINOP_DIVIDE, 0, m, &cBinop_KyDdnmAL_sendMessage);
}

void Heavy_WSTD_EQ::cVar_iSyyWy2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1DU3KUPp, HV_BINOP_DIVIDE, 1, m, &cBinop_1DU3KUPp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KyDdnmAL, HV_BINOP_DIVIDE, 1, m, &cBinop_KyDdnmAL_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_z6opk75Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DtiLfzMR, HV_BINOP_DIVIDE, 0, m, &cBinop_DtiLfzMR_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_uNjGwt1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DtiLfzMR, HV_BINOP_DIVIDE, 1, m, &cBinop_DtiLfzMR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WvBPJqJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iSyyWy2b, 0, m, &cVar_iSyyWy2b_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BMk0EyGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1DU3KUPp, HV_BINOP_DIVIDE, 0, m, &cBinop_1DU3KUPp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wY787swj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UNWKaUzO, 0, m, &cVar_UNWKaUzO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1DU3KUPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_z6opk75Y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KyDdnmAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_uNjGwt1m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DtiLfzMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_GJZ5zv0F_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9Ruc9aaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_c5xeKhQy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gc1aPfbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_NX89H62x_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GJZ5zv0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gc1aPfbn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NX89H62x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_9Ruc9aaW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c5xeKhQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UCktKukU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_mihWz2Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MjHFKOLj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WF8NFTRT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dEkiGv8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MjHFKOLj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WF8NFTRT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5tvp47b3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MjHFKOLj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WF8NFTRT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dKq24g4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MjHFKOLj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WF8NFTRT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UCktKukU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MjHFKOLj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WF8NFTRT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0H8hBIJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_QD0fnlxe, 0, m, &cVar_QD0fnlxe_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_IwAYcGx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_B02kDnM0, 0, m, &cVar_B02kDnM0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kupL5ZNj, 0, m, &cVar_kupL5ZNj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Kh7T4Mj8, 0, m, &cVar_Kh7T4Mj8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_S1Ow8DPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B02kDnM0, 0, m, &cVar_B02kDnM0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_KvdHO3L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kupL5ZNj, 0, m, &cVar_kupL5ZNj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rgjLGeJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kh7T4Mj8, 0, m, &cVar_Kh7T4Mj8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_dsrqBP5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gXFroO3j, 0, m, &cVar_gXFroO3j_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_kbWfoeVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AqMhtyBv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zDlWRfsA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_uqo8JZAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_35vNTDmI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nOTuuhwU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EANXfzGg_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_KCpK9nhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HqMqLfvC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z1HC7NhU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cEoYqLPX_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0HasJXFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IymdAW44_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LihRTbh8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WFHooBTG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lTDA2wbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5R8oGpTo_sendMessage(_c, 0, m);
  cMsg_7FrBoUPU_sendMessage(_c, 0, m);
  cMsg_VfvlHgSe_sendMessage(_c, 0, m);
  cMsg_FuXrvbow_sendMessage(_c, 0, m);
  cMsg_OFHglL23_sendMessage(_c, 0, m);
  cMsg_KX0emTIK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bNxXDaXm, 0, m, &cVar_bNxXDaXm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gXFroO3j, 0, m, &cVar_gXFroO3j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bq772Thi, 0, m, &cVar_Bq772Thi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Of3HMZJw, 0, m, &cVar_Of3HMZJw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NVrdo6vE, 0, m, &cVar_NVrdo6vE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_88Kz8VCu, 0, m, &cVar_88Kz8VCu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FraufON4, 0, m, &cVar_FraufON4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o84dhwz2, 0, m, &cVar_o84dhwz2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uvTKxmKH, 0, m, &cVar_uvTKxmKH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gXZRLooR, 0, m, &cVar_gXZRLooR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_91huKjHy, 0, m, &cVar_91huKjHy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F353yiLW, 0, m, &cVar_F353yiLW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uOHJ3PVW, 0, m, &cVar_uOHJ3PVW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AhLOVB43, 0, m, &cVar_AhLOVB43_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xoHIX5RN, 0, m, &cVar_xoHIX5RN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lk8Dv7Up, 0, m, &cVar_lk8Dv7Up_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1bfdHqvG, 0, m, &cVar_1bfdHqvG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fG2p4jWE, 0, m, &cVar_fG2p4jWE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LC0LFcCq, 0, m, &cVar_LC0LFcCq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JkhhBQzJ, 0, m, &cVar_JkhhBQzJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ln5UaYeY, 0, m, &cVar_Ln5UaYeY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_96JDEnLR, 0, m, &cVar_96JDEnLR_sendMessage);
  cMsg_IwAYcGx0_sendMessage(_c, 0, m);
  cMsg_0H8hBIJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_liR2ah1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k25AO28z, HV_BINOP_MULTIPLY, 0, m, &cBinop_k25AO28z_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_MuEqYNex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Qxo4VQJj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pTScQVsf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EXB3Pnll_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_RRjUJNxl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Gxup8dEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yydL0GVW_sendMessage);
  cMsg_8yivIDb7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_uGdhUZ07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9DWwcIA7, HV_BINOP_MULTIPLY, 0, m, &cBinop_9DWwcIA7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_PUj6gwDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_o5nQAniK_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_wpoSlajG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q1uFYBNM, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q1uFYBNM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GH0yqhZk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KYWzJlwX_sendMessage);
  cMsg_SH2pnKe7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_yjRkCfcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WT31yBlR, HV_BINOP_MULTIPLY, 0, m, &cBinop_WT31yBlR_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_w7J2snC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QZx6EJQf_sendMessage(_c, 0, m);
  cMsg_7ac6qU1j_sendMessage(_c, 0, m);
  cMsg_NhJdrkPM_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_rw3UiP7h_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_d1y5ieAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JVeIIaIR_sendMessage);
  cMsg_EjCNm4dA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_nLIXptl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NVrdo6vE, 0, m, &cVar_NVrdo6vE_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_cZRZtS8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1uOwWS4V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b733VE6c_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gEFhxnYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t2XUdO48_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Lengetd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o5moYQsQ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gSbFEUqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LhS2nO1q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oh8N81eF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f8M7DUZK_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_zxXmdTS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sTZAsGkB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H2W34SNe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kHB9iAO6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_MaqjcbS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ggwqqxZY, HV_BINOP_MULTIPLY, 0, m, &cBinop_ggwqqxZY_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_BQx0EPUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4S5NXd2R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PwHGW5JU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dcotGE5w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_wFKe479g_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_e139hu6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8MbuzBy0_sendMessage);
  cMsg_WFkV084U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_K9LI2W3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WpCBU9Z6, HV_BINOP_MULTIPLY, 0, m, &cBinop_WpCBU9Z6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_RLLRX8FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_wo447MNa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_X8IFh7PB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9a01TSj, HV_BINOP_MULTIPLY, 1, m, &cBinop_d9a01TSj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oJ67W1G0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Qfilc8ST_sendMessage);
  cMsg_dyQOEUN7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_YrYMUJfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tm4tSbzC, HV_BINOP_MULTIPLY, 0, m, &cBinop_tm4tSbzC_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5gO3Z5vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GTeiMuMu_sendMessage(_c, 0, m);
  cMsg_EDJxla3w_sendMessage(_c, 0, m);
  cMsg_cfWCWgMd_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_OQsyVDNn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qVHUfY03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Cm8xcz3J_sendMessage);
  cMsg_2QMb4ITp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_pDsZFDmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QD0fnlxe, 0, m, &cVar_QD0fnlxe_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_fosY6X2T, VOf(Bf0));
    __hv_varread_f(&sVarf_KtK32VLp, VOf(Bf1));
    __hv_varread_f(&sVarf_alyJcKR4, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_IDWwfouK, VOf(Bf0));
    __hv_varread_f(&sVarf_8A2HrBLB, VOf(Bf1));
    __hv_varread_f(&sVarf_XHHpa2sx, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_bZhG2mJA, VOf(Bf0));
    __hv_line_f(&sLine_EXpbeNjS, VOf(Bf1));
    __hv_line_f(&sLine_JldsxYdV, VOf(Bf4));
    __hv_line_f(&sLine_gvkiHgnT, VOf(Bf5));
    __hv_line_f(&sLine_qBf0oTQr, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_n8Fqd2d3, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_dtMLzaxb, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ydtI3lBz, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_GGFk8OIR, VOf(Bf1));
    __hv_line_f(&sLine_LBKTejcO, VOf(Bf0));
    __hv_line_f(&sLine_L0E8zzyz, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_VQWH99BJ, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_UDuDg0qb, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_NQaBwCV9, VOf(Bf7));
    __hv_line_f(&sLine_rXPmsFRb, VOf(Bf1));
    __hv_line_f(&sLine_wFscdfRp, VOf(Bf4));
    __hv_line_f(&sLine_rKcKjTrb, VOf(Bf6));
    __hv_line_f(&sLine_vL8QbiQ4, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_ciHuCBsJ, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_6sS7HCQd, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_fosY6X2T, VIf(Bf5));
    __hv_varwrite_f(&sVarf_KtK32VLp, VIf(Bf0));
    __hv_varwrite_f(&sVarf_alyJcKR4, VIf(Bf6));
    __hv_line_f(&sLine_mLmYYCjb, VOf(Bf6));
    __hv_line_f(&sLine_t1v4tUSr, VOf(Bf0));
    __hv_line_f(&sLine_yMlU0Hot, VOf(Bf5));
    __hv_line_f(&sLine_1p5IABSn, VOf(Bf8));
    __hv_line_f(&sLine_0iIXP59a, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_3Sls51ut, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_thl23ZGW, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_GlMVmWy3, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_QrTTpkCN, VOf(Bf0));
    __hv_line_f(&sLine_mYLjS90O, VOf(Bf6));
    __hv_line_f(&sLine_5PZGh9zr, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_K3y1Aswr, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_RANnAcef, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_MD7JkkXP, VOf(Bf1));
    __hv_line_f(&sLine_rNc75q6f, VOf(Bf0));
    __hv_line_f(&sLine_tPCoPcpg, VOf(Bf5));
    __hv_line_f(&sLine_9UES8ZTy, VOf(Bf4));
    __hv_line_f(&sLine_yUrY0Y5O, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_Kwh8jbzQ, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_DJyXn6JK, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_IDWwfouK, VIf(Bf8));
    __hv_varwrite_f(&sVarf_8A2HrBLB, VIf(Bf6));
    __hv_varwrite_f(&sVarf_XHHpa2sx, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
